/**
 * @package css-modules-types-loader
 * @license MIT
 * @version 0.3.31
 * @author nuintun <nuintun@qq.com>
 * @description A webpack loader that dynamically generates TypeScript typings for CSS modules from css-loader.
 * @see https://github.com/nuintun/css-modules-types-loader#readme
 */

import { Pool, spawn, Worker } from 'threads';

/**
 * @module index
 */
const pool = Pool(() => {
  return spawn(new Worker('./generate.js'));
});
/**
 * @function terminate
 * @description Terminates the pool.
 * @param force If set to true, forcefully terminates the pool.
 */
async function terminate(force) {
  return pool.terminate(force);
}
/**
 * @function generate
 * @description Generates a file at the specified path with the provided content.
 * @param path The path where the file will be generated.
 * @param content The content of the file.
 * @param options Optional options for file generation.
 */
async function generate(path, content, options) {
  pool.queue(async generate => {
    await generate(path, content.toString(), options);
  });
  await pool.completed();
}

export { generate, terminate };
