/**
 * @package css-modules-types-loader
 * @license MIT
 * @version 0.3.31
 * @author nuintun <nuintun@qq.com>
 * @description A webpack loader that dynamically generates TypeScript typings for CSS modules from css-loader.
 * @see https://github.com/nuintun/css-modules-types-loader#readme
 */

import { schema } from './schema.js';
import { terminate, generate } from './generate/index.js';

/**
 * @module index
 */
const name = 'css-modules-types-loader';
const initialized = Symbol(name);
const loader = function loader(content, sourceMap, additionalData) {
  const callback = this.async();
  const logger = this.getLogger(name);
  const options = this.getOptions(schema);
  const { _compiler: compiler } = this;
  if (compiler) {
    if (!compiler[initialized]) {
      compiler[initialized] = true;
      if (compiler.watchMode) {
        compiler.hooks.watchClose.tap(name, () => terminate());
      } else {
        compiler.hooks.done.tapPromise(name, () => terminate());
      }
    }
  }
  callback(null, content, sourceMap, additionalData);
  generate(`${this.resourcePath}.d.ts`, content, options).catch(error => {
    logger.error(error.message);
  });
};

export { loader as default };
