/**
 * @module utils
 */
/// <reference types="node" />
import fs from 'fs';
import { Node } from 'estree';
export declare const rm: typeof fs.rm.__promisify__;
export declare const writeFile: typeof fs.writeFile.__promisify__;
export type Styles = [key: string, value: string][];
/**
 * @function removeFile
 * @description Removes a file from the filesystem if it exists.
 * @param path The path to the file.
 */
export declare function removeFile(path: string): Promise<void>;
/**
 * @function isString
 * @description Checks if a value is a string.
 * @param value The value to check.
 */
export declare function isString(value: unknown): value is string;
/**
 * @function collect
 * @description Collects styles from the given nodes and adds them to the styles array.
 * @param styles The array to which the collected styles will be added.
 * @param left The left node.
 * @param right The right node.
 */
export declare function collect(styles: Styles, left: Node, right: Node): void;
/**
 * @function parseStyles
 * @description Parses the styles from the given content.
 * @param content The content to parse the styles from.
 */
export declare function parseStyles(content: string): [styles: Styles, named: boolean];
/**
 * @function generateTypings
 * @description Generate typings for CSS modules.
 * @param content The CSS content.
 * @param banner Optional banner string.
 * @param eol End of line character.
 */
export declare function generateTypings(content: string, banner?: string, eol?: string): string | null;
